..  Copyright (C)  Barbara Ericson and Allen B. Downey

Acknowledgements
=================
This interactive ebook is based on a book by Allen B. Downey.  See
https://open.umn.edu/opentextbooks/textbooks/how-to-think-like-a-computer-scientist-c-version

We thank Brad Miller for all of his tremendous work on Runestone including getting C++ to work,
adding unit tests for C++, and adding a visualizer for C++.

Contributor List
==================
* Barbara Ericson - Led the effort to make this ebook interactive
* Ewelina Papiez - Added interactive questions to the ebook
* Mariah Zeweke - Added interactive questions to the ebook
* Richard Wang - Added interactive questions to the ebook
* Sravani Battula - Added interactive questions to the ebook
* Haochen Yu - Added interactive questions to the ebook
* Charles Alford IV - Added interactive questions to the ebook
